<?php
/*
* Plugin Name: DigiMasterTools Email sync for Klick Tipp and WooCommerce
* Plugin URI: https://digimastertools.com/
* Description: Das ultimative Tool, um Kunden von Woocomerce nach Klick Tipp zu übertragen. Nach jedem Kauf wird der Kontakt mit den Produkt Tags nach Klick Tipp übertragen.
* Version: 1.0.6
* Author: Konstantin Peterson
*/

class EmailSyncDigiMasterTools_Connect {

    var $api;
    var $login;
    var $license_domain = 'https://digimastertools.com';

    public function __construct() {
        // connect to Klick Tipp API
        if($this->api == '') {
            $this->api = $this->klickTippInitAPI();
        }

        // login to Klick Tipp
        $this->login();
    }
    // Klick Tipp initialisieren und einloggen
    function klickTippInitAPI() {
        
        require_once( plugin_dir_path( __FILE__ ) . 'klicktipp.api.inc.php');
        $username = get_option('dmwkti_username'); // Replace with username
        $password = get_option('dmwkti_password'); // Replace with password
        
        $connector = new DMWKTI_KlicktippConnectorForApi();
        $login = $connector->login($username, $password);
        
        #$connector->logout();
        return $connector;
    }
    function login() {
        $username = get_option('dmwkti_username'); // Replace with username
        $password = get_option('dmwkti_password'); // Replace with password   
        $this->login = $this->api->login($username, $password);
    }
    function allKlickTippTags() {
        return $this->api->tag_index();
    }
    function allSubscriberFields() {
        return $this->api->field_index();
    }

    // beim checkout werden daten an Klick Tipp übertragen
    function checkout_process_to_klicktipp($order_id) {

        // display erros
        // echo ausgabe in dieser Funktion
        // look at Elemente Untersuchen -> Network -> Fetch XHR
        // click dann auf Zeile ?wc-ajax=checkout
                #error_reporting(E_ALL);
                #ini_set('display_errors', 1);

        $order = new WC_Order($order_id);
        $order_data = $order->get_data(); // The Order data

        $total_price = $order->get_total();

        $order_status = $order_data['status'];

        #$status_allowed = array('processing', 'completed');

        // globale tags
        $set_tag_category = get_option('dmwkti_tag_category');
        $set_tag_product_name = get_option('dmwkti_tag_product_name');
        $global_tag_array_settigs = json_decode(get_option('dmwkti_global_tag'), true);
        $product_settings = json_decode(get_option('dmwkti_product'), true);
        $product_settings_free = json_decode(get_option('dmwkti_product_free'), true);

        // get license
        $license = $this->check_license();

        // customer details
        $email = $order_data['billing']['email'];
        $firstname = $order_data['billing']['first_name'];
        $lastname = $order_data['billing']['last_name'];
        $company = $order_data['billing']['company'];
        $address_1 = $order_data['billing']['address_1'];
        $address_2 = $order_data['billing']['address_2'];
        $city = $order_data['billing']['city'];
        $state = $order_data['billing']['state'];
        $postcode = $order_data['billing']['postcode'];
        $country = $order_data['billing']['country'];
        $phone = $order_data['billing']['phone'];


        // for each product
        // product & generate tags
        $items = $order->get_items();
        $product_taglist = Array();
        $product_taglist = array();
        global $product;
        foreach ( $items as $item ) {
            $product_id = $item['product_id'];
            $prodcut_name = $item['name'];

            // product category
            $categories_array = get_the_terms( $product_id, 'product_cat' );
            $product_categorie_array = array();
            if($categories_array) {
                foreach($categories_array as $cat) {
                    $product_categorie_array[] = $cat->name;
                }
            }

            // get product post_meta tag settings
            $dmwkti_product_settings = json_decode(get_post_meta($product_id, 'dmwkti_product_settings', true), true);
            if($dmwkti_product_settings) {
                // if exists override old option product tag
                $product_settings[$product_id] = $dmwkti_product_settings;
            }

            // generate tags
            if( ($product_settings[$product_id] and $product_settings[$product_id]['setting']) or $product_settings_free) {

                $product_setting = $product_settings[$product_id]['setting'];
                $product_setting_tag_temp = $product_settings[$product_id]['tag'];
                $product_tag_status = $product_settings[$product_id]['status'];


                $product_setting_tag_free = '';
                if(isset($product_settings_free[$product_id]['tag'])) {
                    $product_setting_tag_free = $product_settings_free[$product_id]['tag'];
                }

                // clean product tags by order_status
                if($product_setting_tag_temp) {
                    foreach($product_setting_tag_temp as $tag_key => $tag_value) {

                        // if order_status match tag-status
                        if( empty($product_tag_status[$tag_key]) ) {
                            $product_setting_tag[$tag_key] = $tag_value;
                        }
                        else if($product_tag_status[$tag_key] == $order_status) {
                            $product_setting_tag[$tag_key] = $tag_value;
                        }

                    }
                }

                // clean global tags by order_status
                if($global_tag_array_settigs) {

                    foreach($global_tag_array_settigs as $global_tag_key => $global_tag_value) {

                        // if array than check status
                        if( is_array($global_tag_value) ) {
                            // if order_status match tag-status
                            if( empty($global_tag_value['status']) ) {
                                $global_tag_array[$global_tag_key] = $global_tag_value['tag'];
                            }
                            else if($global_tag_value['status'] == $order_status) {
                                $global_tag_array[$global_tag_key] = $global_tag_value['tag'];
                            }
                        }
                        else {
                            $global_tag_array[$global_tag_key] = $global_tag_value;
                        }

                    }
                }

                // active license
                if($license == 'OK') {
                    
                    switch($product_setting) {
                        case 'add':
                            // get product category
                            if($set_tag_category and $product_categorie_array) {
                                $product_taglist[$product_id]['category'] = $product_categorie_array; 
                            }
                            // set product name
                            if($set_tag_product_name) {
                                $product_taglist[$product_id]['name'][] = $prodcut_name;
                            }
                            // set global tags
                            if($global_tag_array) {
                                $product_taglist[$product_id]['global_tag'] = $global_tag_array;
                            }
                            // set produkt tags
                            if($product_setting_tag) {
                                $product_taglist[$product_id]['tag_id'] = $product_setting_tag;
                            }
                            break;
                        case 'only':
                            // set produkt tags
                            if($product_setting_tag) {
                                $product_taglist[$product_id]['tag_id'] = $product_setting_tag;
                            }
                            break;
                        case 'category':
                            // get product category
                            if($set_tag_category and $product_categorie_array) {
                                $product_taglist[$product_id]['category'] = $product_categorie_array; 
                            }
                            // set produkt tags
                            if($product_setting_tag) {
                                $product_taglist[$product_id]['tag_id'] = $product_setting_tag;
                            }
                            break;
                        case 'prod_name':
                            // set product name
                            if($set_tag_product_name) {
                                $product_taglist[$product_id]['name'][] = $prodcut_name;
                            }
                            // set produkt tags
                            if($product_setting_tag) {
                                $product_taglist[$product_id]['tag_id'] = $product_setting_tag;
                            }
                            break;
                        case 'glob_tag':
                            // set global tags
                            if($global_tag_array) {
                                $product_taglist[$product_id]['global_tag'] = $global_tag_array;
                            }
                            // set produkt tags
                            if($product_setting_tag) {
                                $product_taglist[$product_id]['tag_id'] = $product_setting_tag;
                            }
                            break;
                    }
                }
                // free license
                else {
                    // set produkt tags
                    if($product_setting_tag_free) {
                        $product_taglist[$product_id]['tag_id'] = $product_setting_tag_free;
                    }
                }

            }
        }

        // generate complete klick tipp tag-id list
        $taglist = array();
        if($product_taglist) {
            $all_klick_tipp_tags = $this->allKlickTippTags();
            foreach($product_taglist as $product_list) {

                // category global
                if(isset($product_list['category'])) {
                    foreach($product_list['category'] as $tag) {
                        if(in_array($tag, $all_klick_tipp_tags)) {
                            $tag_id = array_search($tag, $all_klick_tipp_tags);
                        }
                        else {
                            // create tag in klick tipp and get tag_id
                            $this->api->tag_create($tag);
                            unset($all_klick_tipp_tags);
                            $all_klick_tipp_tags = $this->allKlickTippTags();
                            $tag_id = array_search($tag, $all_klick_tipp_tags);
                        }
                        $taglist[] = $tag_id;
                    }
                }
                // product name global
                if(isset($product_list['name'])) {
                    foreach($product_list['name'] as $tag) {
                        if(in_array($tag, $all_klick_tipp_tags)) {
                            $tag_id = array_search($tag, $all_klick_tipp_tags);
                        }
                        else {
                            // create tag in klick tipp and get tag_id
                            $this->api->tag_create($tag);
                            unset($all_klick_tipp_tags);
                            $all_klick_tipp_tags = $this->allKlickTippTags();
                            $tag_id = array_search($tag, $all_klick_tipp_tags);
                        }
                        $taglist[] = $tag_id;
                    }
                }
                // global tags
                if(isset($product_list['global_tag'])) {
                    foreach($product_list['global_tag'] as $tag_id) {
                        $taglist[] = $tag_id;
                    }
                }

                // product tags
                if(isset($product_list['tag_id'])) {
                    foreach($product_list['tag_id'] as $tag_id) {
                        $taglist[] = $tag_id;
                    }
                }
            }
        }

        if(isset($_POST['dmwkti_checkout_checkbox']) and $_POST['dmwkti_checkout_checkbox'] == 1) {
            $taglist[] = get_option('dmwkti_checkbox_checkout_tag');
        }

        $total_price = str_replace('.', '', $total_price);

        // add LeadValue from Klick Tipp
        $subscriber_id = $this->api->subscriber_search($email);
        if($subscriber_id) {
            $subscriber = $this->api->subscriber_get($subscriber_id);    
            $total_price = floatval($total_price) + floatval($subscriber->fieldLeadValue);
        }

        // default fields
        $fields = array(
            'email' => $email,
            'fieldFirstName' => $firstname,
            'fieldLastName' => $lastname,
            'fieldCompanyName' => $company,
            'fieldStreet1' => $address_1,
            'fieldStreet2' => $address_2,
            'fieldCity' => $city,
            'fieldState' => $state,
            'fieldZip' => $postcode,
            'fieldCountry' => $country,
            'fieldPhone' => $phone,
            'fieldLeadValue' => $total_price,
        );

        // set double opt in
        if(get_option('dmwkti_optin')) {
            $listid = get_option('dmwkti_optin');
        }
        else {
            $listid = 0;
        }

        // create new user in klick tipp
        $this->api->subscribe($email, $listid, $tagid = 0, $fields, $smsnumber = '');
        // insert tags
        $this->api->tag($email, $taglist);

    }

    function import_all_orders() {
        // get all orders
        $args = array(
            'limit' => 99999999,
            'return' => 'ids',
        );
        $query = new WC_Order_Query( $args );
        $orders = $query->get_orders();

        if($orders) {
            foreach($orders as $key => $order_id) {
                $this->checkout_process_to_klicktipp($order_id);
            }
        }

        $all_orders = count($orders);

        return $all_orders;
    }

    function check_license() {
        $license_status = $this->license_status();
        return $license_status;
    }

    function license_status() {
        $license_key = get_option('dmwkti_license');
        $domain = sanitize_url($_SERVER['SERVER_NAME']);
        $domain = str_replace('https://', '', $domain);
        $domain = str_replace('http://', '', $domain);
        $domain = str_replace('www.', '', $domain);
        $license_domain = $this->license_domain;

        $url = $license_domain.'/license_assistent/get-license?license_key='.$license_key.'&domain='.$domain;

        $result = '';
        $response = wp_remote_get( $url );
        $result = wp_remote_retrieve_body( $response );
        return $result;
    }
}


//get all woocomerce producs
function dm_email_sync_getAllProducts() {

    $args = array(
        'post_type' => 'product',
        'posts_per_page' => '20',
    );

    // search by name
    if(isset($_GET['search']) and $_GET['search']) {
        $args['s'] = trim( sanitize_text_field( $_GET['search'] ) );
    }
    if(isset($_GET['p']) and $_GET['p']) {
        $args['paged'] = trim( sanitize_text_field( $_GET['p'] ) );
    }

    $wp_query = new WP_Query($args);
    $products = $wp_query->posts;
    #$wp_query->max_num_pages;

    if($products) {
        foreach($products as $key => $value) {
            $product_list[$value->ID]['name'] = $value->post_title;
            $product_list[$value->ID]['dmwkti_product_settings'] = json_decode(get_post_meta($value->ID, 'dmwkti_product_settings', true), true);
        }
    }

    $product_list_result = array(
        'total' => $wp_query->found_posts,
        'pages' => $wp_query->max_num_pages,
        'product_list' => $product_list,
    );

    return $product_list_result;
}

// Add Menu for Dashboard
add_action('admin_menu', 'dm_email_sync_admin_menu');
function dm_email_sync_admin_menu(){
    add_menu_page('Email Synch for Klick Tipp and WooCommerce', 'Email Sync', 'manage_options', 'digimastertools-email-sync-setting', 'dm_email_sync_init', 'dashicons-email', '90');
}

// Einstellungen
function dm_email_sync_init() {

    $search = '';
    if(isset($_GET['search'])) {
        $search = sanitize_text_field( $_GET['search'] );
    }
    $p = '';
    if(isset($_GET['p'])) {
        $p = sanitize_text_field( $_GET['p'] );
    }
    $submit = '';
    if(isset($_GET['p'])) {
        $submit= sanitize_text_field( $_GET['submit'] );
    }

    $KlickTipp = new EmailSyncDigiMasterTools_Connect();
    
    // Verbinde mit Klick Tipp
    $api = $KlickTipp->api;
    // Prüfe ob eingeloggt
    $login = $KlickTipp->login;
    // get Opt-in list
    $optin_list = $api->subscription_process_index();

    //get woocomerce producs
    $products_list_result = dm_email_sync_getAllProducts();
    $product_total_products = $products_list_result['total'];
    $product_total_pages = $products_list_result['pages'];
    $products = $products_list_result['product_list'];

    //alle Klick Tipp Tags
    $all_tags = $KlickTipp->allKlickTippTags();
    #echo '<pre>';print_r($all_tags); echo '</pre>';

    $all_subscriberFields = $KlickTipp->allSubscriberFields();

    // import
    if(isset($_GET['import_all_orders']) and $_GET['import_all_orders'] == '1') {
        $all_orders = $KlickTipp->import_all_orders();
        $url = '/wp-admin/admin.php?page=digimastertools-email-sync-setting&import_orders=completed&orders='.$all_orders;
        wp_redirect( $url );
        exit;
    }

    $dmwkti_tag_category = get_option('dmwkti_tag_category');
    $dmwkti_tag_product_name = get_option('dmwkti_tag_product_name');
    $global_tag_array = json_decode(get_option('dmwkti_global_tag'), true);
    $product = json_decode(get_option('dmwkti_product'), true);
    $product_free = json_decode(get_option('dmwkti_product_free'), true);
    
    $license = $KlickTipp->check_license();

    if($license == 'OK') {
        $license_string = '<span style="border-radius: 4px;background: #12a500;color: #fff;padding: 3px 8px 3px 3px;"><span style="margin-top: 4px;" class="dashicons dashicons-yes"></span> Plugin ist lizensiert!</span> <a href="?page=digimastertools-email-sync-setting&license=release">Lizenz freigeben</a>';
    }
    else if($license == 'Lizenz ist nicht bezahlt!') {
        $license_string = '<span style="border-radius: 4px;background: #a50000;color: #fff;padding: 3px 8px 3px 3px;"><span style="margin-top: 4px;" class="dashicons dashicons-no"></span> Die Lizenz ist nicht bezahlt! Funktionen sind eingeschränkt!</span> <a href="http://digimastertools.com" target="_blank">Lizenz erwerben</a>';
    } 
    else {
        $license_string = '<span style="border-radius: 4px;background: #a50000;color: #fff;padding: 3px 8px 3px 3px;"><span style="margin-top: 4px;" class="dashicons dashicons-no"></span> Plugin ist noch nicht lizensiert! Funktionen sind eingeschränkt!</span> <a href="http://digimastertools.com" target="_blank">Lizenz erwerben</a>';
    }

    ?>
    <style type="text/css">
        .title-descr {
            font-weight: normal;
            font-size: 10px;
        }
        .tooltipicon  {
            position: relative;
            display: inline-block;
            background: #a5a5a5;
            border-radius: 100px;
            width: 18px;
            text-align: center;
            color: #fff;
        }
        .tooltipicon .tooltipcontent {
            display: none;
            width:300px;
            color: #333;
            position: absolute;
            background: white;
            padding: 10px;
            border-radius: 4px;
            box-shadow: 0 0 4px #cacaca;
            left: 20px;
            top: -7px;
            font-size: 12px;
             -moz-transition: all .5s ease;
            -webkit-transition: all .5s ease;
            -o-transition: all .5s ease;
            transition: all .5s ease;
        }
        .tooltipicon:hover .tooltipcontent {
            display: block;
        }

        .message-action {
            font-weight: bold;
            color: #ffffff;
            background: #11a503;
            padding: 10px;
        }
        .notice { display: none;}
        #savebox p{
            background: #12a500;
            color: #fff;
            padding: 10px;
            display: inline-block;
            border-radius: 6px;
        }
    </style>
    <div class="wrap">

        <?php
        if(isset($_SESSION['DMWKTI_save_settings']) and $_SESSION['DMWKTI_save_settings']) {
            echo '<div id="savebox"><p>'.esc_html($_SESSION['DMWKTI_save_settings']).'</p></div>';
            unset($_SESSION['DMWKTI_save_settings']);
        }
        ?>

      <h1>WooCommerce Klick Tipp Interface - Einstellungen</h1>
      <p>Du hast Fragen zum Plugin oder bei dir scheint etwas nicht zu funktioniert? Schreibe mir: <a href="mailto:mail@digimastertools.com">mail@digimastertools.com</a></p>


        <?php
        if(isset($_GET['import_orders']) and $_GET['import_orders'] == 'completed') {
            echo '<p class="message-action">Alle ('.esc_html($_GET['orders']).') Bestellungen wurden nach Klick Tipp importiert. <span class="dashicons dashicons-yes"></span></p>';
        }
        ?>

        <?php
        if($login == 1) {
            echo '<div style="background: #12a500;color: #fff;padding: 10px;"><span class="dashicons dashicons-yes"></span> Mit Klick Tipp verbunden</div>';
        }
        else {
            echo  '<div style="background: #a50000;color: #fff;padding: 10px;"><span class="dashicons dashicons-no"></span> Verbindung zu Klick Tipp nicht vorhanden! Bitte überprüfe Benutzername und Passwort von Klick Tipp!</div>';
        }
        ?>

        <form style="background: #fff;padding: 20px;" method="post" action="?page=<?php echo esc_html($_GET['page']);?>&search=<?php echo esc_html($search);?>&p=<?php echo esc_html($p);?>">

            <h2>Verbindung herstellen</h2>

            <table class="form-table">
                <tbody>
                    <tr>
                        <th style="padding: 0px 10px 0px 0;" scope="row">Benutzername <span class="title-descr">(Klick Tipp)</span></th>
                        <td style="padding: 0px 10px 0px 10px;">
                            <div class="category_for_posts_row">
                                <input type="text" name="dmwkti_username" value="<?php echo esc_html(get_option('dmwkti_username'));?>">
                            </div>
                        </td>
                    </tr>
                    <tr>
                        <th style="padding: 0px 10px 0px 0;" scope="row">Passwort <span class="title-descr">(Klick Tipp)</span></th>
                        <td style="padding: 0px 10px 0px 10px;">
                            <div class="category_for_posts_row">
                                <input type="password" name="dmwkti_password" value="<?php echo esc_html(get_option('dmwkti_password'));?>">
                            </div>
                        </td>
                    </tr>
                    <tr>
                        <th style="padding: 0px 10px 0px 0;" scope="row">Lizenz Key <span class="title-descr">(DigiMasterTools)</span></th>
                        <td style="padding: 0px 10px 0px 10px;">
                            <div class="category_for_posts_row">
                                <input type="text" name="dmwkti_license" value="<?php echo esc_html(get_option('dmwkti_license'));?>"> <?php echo wp_kses_post($license_string);?>
                            </div>
                        </td>
                    </tr>
                </tbody>
            </table>
            <?php
            if($login == 1) { ?>

            <hr>

            <table class="form-table">
                <tbody>
                    
                    <tr>
                        <th scope="row">Opt-In Prozess</th>
                        <td>
                            <div class="category_for_posts_row">
                                <select name="dmwkti_optin">
                                    <?php 
                                    if($optin_list) {
                                        foreach($optin_list as $id => $list) {
                                            $selected = '';
                                            if(get_option('dmwkti_optin') == $id) {
                                                $selected = 'selected';
                                            }
                                            if($list == '') {
                                                $list = 'Vordefinierter Double-Opt-In-Prozess';
                                            }

                                            ?>
                                            <option value="<?php echo esc_html($id);?>" <?php echo esc_html($selected);?>><?php echo esc_html($list);?></option>
                                            <?php
                                        }
                                    }
                                    ?>
                                </select>
                            </div>
                        </td>
                    </tr>

                    <tr style="border-top: 1px solid #dddddd;">
                        <th colspan="2" scope="row">Globale Einstellung<br>
                        <span style="font-weight: normal">Wähle welche Tags beim Kauf an Klick Tipp übergeben werden sollen:</span><br>
                        <span style="font-weight: normal">(Falls diese Tags nicht übergeben werden, dann abwählen, speichern, neu selektieren und speichern!)</span><br><br>
                    
                

                            <?php 
                            if($license == 'OK') {
                                ?>
                                <input type="hidden" name="dmwkti_plugin_license" value="paid">
                                <input type="checkbox" name="dmwkti_tag_category" value="1" <?php if($dmwkti_tag_category == 1) {echo 'checked';} ?> >
                                <span style="font-weight: normal">Produkt Kategorie als Tag</span><br>

                                <input type="checkbox" name="dmwkti_tag_product_name" value="1" <?php if($dmwkti_tag_product_name == 1) {echo 'checked';} ?>>
                                <span style="font-weight: normal">Produkt Name als Tag</span><br>

                                <?php
                                if(is_array($global_tag_array) and $global_tag_array) {
                                    foreach($global_tag_array as $key => $tag_array) {

                                        if(is_array($tag_array) ) {

                                            $global_tag_id = $tag_array['tag'];
                                            $global_tag_status = $tag_array['status'];

                                        }
                                        else {
                                            $global_tag_id = $tag_array;
                                        }


                                        if($global_tag_id) {
                                            ?>
                                            <div class="category_for_posts_row">
                                                <select class="dmwkti-product-tag" name="dmwkti_global_tag[]">
                                                    <option value=""></option>
                                                    <?php
                                                    if($all_tags) {
                                                        foreach($all_tags as $tag_id => $tag) {
                                                            $selected = '';
                                                            if($global_tag_id == $tag_id) {
                                                                $selected = 'selected';
                                                            }
                                                            ?>
                                                            <option value="<?php echo esc_html($tag_id);?>" <?php echo esc_html($selected);?>><?php echo esc_html($tag);?></option>
                                                            <?php
                                                        }
                                                    }
                                                    ?>
                                                </select>
                                                <select class="status" name="dmwkti_global_tag_status[]">
                                                    <option value="">Status Alle</option>
                                                    <option value="pending" <?php if($global_tag_status == 'pending') {echo 'selected'; } ?> >Zahlung ausstehend</option>
                                                    <option value="processing" <?php if($global_tag_status == 'processing') {echo 'selected'; } ?> >In Bearbeitung</option>
                                                    <option value="on-hold" <?php if($global_tag_status == 'on-hold') {echo 'selected'; } ?> >In Wartestellung</option>
                                                    <option value="completed" <?php if($global_tag_status == 'completed') {echo 'selected'; } ?> >Abgeschlossen</option>
                                                    <option value="cancelled" <?php if($global_tag_status == 'cancelled') {echo 'selected'; } ?> >Storniert</option>
                                                    <option value="refunded" <?php if($global_tag_status == 'refunded') {echo 'selected'; } ?> >Rückerstattet</option>
                                                    <option value="failed" <?php if($global_tag_status == 'failed') {echo 'selected'; } ?> >Fehlgeschlagen</option>
                                                </select>
                                                 <span style="font-weight: normal">Globales Tag</span>
                                            </div>
                                        <?php 
                                        }
                                    }
                                }
                                ?>
                                <div class="category_for_posts_row">
                                    <select class="dmwkti-product-tag" name="dmwkti_global_tag[]">
                                        <option value=""></option>
                                        <?php 
                                        if($all_tags) {
                                            foreach($all_tags as $tag_id => $tag) {
                                                $selected = '';
                                                if(get_option('dmwkti_global_tag_'.$product_id) == $tag_id) {
                                                    $selected = 'selected';
                                                }
                                                ?>
                                                <option value="<?php echo esc_html($tag_id);?>" <?php echo esc_html($selected);?>><?php echo esc_html($tag);?></option>
                                                <?php
                                            }
                                        }
                                        ?>
                                    </select>
                                    <select class="status" name="dmwkti_global_tag_status[]">
                                        <option value="">Status Alle</option>
                                        <option value="pending">Zahlung ausstehend</option>
                                        <option value="processing">In Bearbeitung</option>
                                        <option value="on-hold">In Wartestellung</option>
                                        <option value="completed">Abgeschlossen</option>
                                        <option value="cancelled">Storniert</option>
                                        <option value="refunded">Rückerstattet</option>
                                        <option value="failed">Fehlgeschlagen</option>
                                    </select>
                                    <span style="font-weight: normal">Globale Tags</span>

                                </div>

                                <?php 
                            }
                            else { ?>
                                <input type="hidden" name="dmwkti_plugin_license" value="free">
                                <input type="checkbox" name="dmwkti_tag_category" value="1" <?php if($dmwkti_tag_category == 1) {echo 'checked';} ?> disabled>
                                <span style="font-weight: normal">Produkt Kategorie als Tag</span> <span style="color: #a50000;">(Nur mit Lizenz verfügbar)</span><br>

                                <input type="checkbox" name="dmwkti_tag_product_name" value="1" <?php if($dmwkti_tag_product_name == 1) {echo 'checked';} ?> disabled> 
                                <span style="font-weight: normal">Produkt Name als Tag</span> <span style="color: #a50000;">(Nur mit Lizenz verfügbar)</span><br>

                                <div class="category_for_posts_row">
                                    <select class="dmwkti-product-tag" name="dmwkti_global_tag[]" disabled>
                                        <option value=""></option>
                                        <?php 
                                        if($all_tags) {
                                            foreach($all_tags as $tag_id => $tag) {
                                                $selected = '';
                                                if(get_option('dmwkti_global_tag_'.$product_id) == $tag_id) {
                                                    $selected = 'selected';
                                                }
                                                ?>
                                                <option value="<?php echo esc_html($tag_id);?>" <?php echo esc_html($selected);?>><?php echo esc_html($tag);?></option>
                                                <?php
                                            }
                                        }
                                        ?>
                                    </select> <span style="font-weight: normal">Globale Tags</span> <span style="color: #a50000;">(Nur mit Lizenz verfügbar)</span>
                                </div>

                                <p>
                                <a style="background-color:#FE004E;border-color:#FE004E;" class="button button-primary" target="_blank" href="https://digimastertools.com/">Auf Vollversion upgraden</a>
                                </p>
                                <?php
                            }
                            ?>
                        </th>
                    </tr>

                </tbody>
            </table>

            <?php submit_button('Einstellungen speichern'); ?>
        </form>

        <br>

            <h3 id="product-settings">Produkt Einstellung</h3>

            <p>Verbinde WooCommerce Produkte mit Klick Tipp Tags.</p>

        <style>
            #search-product-form{
                text-align: right;
                max-width: 970px;
            }
            #pagination-box {
                text-align: right;
                max-width: 970px;
            }
            #pagination a {
                background: #ffffff;
                padding: 3px 6px;
                border-radius: 4px;
                color: #000;
                margin: 0 4px;
                box-shadow: 0 1px 5px 0px #00000059;
                text-decoration: none;
            }
            #pagination .active{
                background: #ededed;
            }
        </style>


            <div id="search-product-form">
                <form method="GET" action="/wp-admin/admin.php">
                <input type="hidden" name="page" value="<?php echo esc_html($_GET['page']);?>">
                <input id="search-product-input" type="search" name="search" placeholder="Suche Produkt" value="<?php echo esc_html($search);?>">
                <!--<a id="submit-search-product" href="javascript: void(0)">Suchen</a>-->
                <?php  submit_button('Suchen', $type = 'primary', $name = 'submit', $wrap = false, $other_attributes = null); ?>
                </form>
            </div>

            <style>
                table th {
                    text-align: left;
                }
                #table-products .product-title {
                    width: 200px;
                    text-align: left;
                }
                #table-products tr {
                    display: inline-block;
                }
                #table-products tbody tr {
                    border-bottom: 1px solid #dadada;
                    padding: 2px 0;
                }
                #table-products tbody tr:last-child {
                    border-bottom: 0px solid #dadada;
                    padding: 2px 0;
                }
                #table-products tbody tr select {
                    margin-bottom: 3px;
                }

            </style>

        <form method="post" action="?page=<?php echo esc_html($_GET['page']);?>&search=<?php echo esc_html($search);?>&p=<?php echo esc_html($p);?>">

            <input type="hidden" name="wktiform-product-settings" value="1">
            <?php
            if($license == 'OK') { ?>
                <input type="hidden" name="dmwkti_plugin_license" value="paid">
            <?php }
            else { ?>
                <input type="hidden" name="dmwkti_plugin_license" value="free">
            <?php } ?>


            <table id="table-products">

                <thead>
                <tr>
                    <th class="product-title" scope="row">Produkte</th>
                    <td style="font-weight: bold;">Klick Tipp Tags</td>
                </tr>
                </thead>
                <tbody>
                    <?php
                    if($license == 'OK') {
                        if($products) {
                            foreach($products as $product_id => $product_item) {

                                $product_name = $product_item['name'];
                                $product_settings = $product_item['dmwkti_product_settings'];

                                $product_setting = array();
                                $product_tag = array();
                                $product_status = array();

                                //post_meta
                                if(isset($product_settings['setting'])) {
                                    $product_setting = $product_settings['setting'];
                                }
                                if($product_settings['tag']) {
                                    $product_tag = $product_settings['tag'];
                                }
                                if($product_settings['status']) {
                                    $product_status = $product_settings['status'];
                                }

                                // backup for old version, load from option value
                                if(empty($product_settings['tag'])) {
                                    if(isset($product[$product_id]['setting'])) {
                                        $product_setting = $product[$product_id]['setting'];
                                    }
                                    if(isset($product[$product_id]['tag'])) {
                                        $product_tag = $product[$product_id]['tag'];
                                    }
                                    if(isset($product[$product_id]['status'])) {
                                        $product_status = $product[$product_id]['status'];
                                    }
                                }
                                ?>
                            <tr>
                                <th class="product-title" scope="row"><?php echo esc_html($product_name);?></th>
                                <td>
                                    <div class="category_for_posts_row">
                                        <select class="dmwkti-product-tag" name="product[<?php echo esc_html($product_id);?>][tag][]">
                                            <option value=""></option>
                                            <?php 
                                            // top select is empty
                                            if($all_tags) {
                                                foreach($all_tags as $tag_id => $tag) {
                                                    $selected = '';
                                                    ?>
                                                    <option value="<?php echo esc_html($tag_id);?>" <?php echo esc_html($selected);?>><?php echo esc_html($tag);?></option>
                                                    <?php
                                                }
                                            }
                                            ?>
                                        </select>
                                        <select class="status" name="product[<?php echo esc_html($product_id);?>][status][]">
                                            <option value="">Status Alle</option>
                                            <option value="pending">Zahlung ausstehend</option>
                                            <option value="processing">In Bearbeitung</option>
                                            <option value="on-hold">In Wartestellung</option>
                                            <option value="completed">Abgeschlossen</option>
                                            <option value="cancelled">Storniert</option>
                                            <option value="refunded">Rückerstattet</option>
                                            <option value="failed">Fehlgeschlagen</option>
                                        </select>

                                        <select class="action" name="product[<?php echo esc_html($product_id);?>][setting]">
                                            <option value="add" <?php echo ($product_setting == 'add' ? 'selected' : ''); ?> >Zusätzliche Tags</option>
                                            <option value="only" <?php echo ($product_setting == 'only' ? 'selected' : ''); ?> >Nur diese Tags</option>
                                            <option value="category" <?php echo ($product_setting == 'category' ? 'selected' : ''); ?> >Mit Kategorie Tag</option>
                                            <option value="prod_name" <?php echo ($product_setting == 'prod_name' ? 'selected' : ''); ?> >Mit Produkt Namen Tag</option>
                                            <option value="glob_tag" <?php echo ($product_setting == 'glob_tag' ? 'selected' : ''); ?> >Mit globalen Tags</option>
                                        </select>
                                        <span class="tooltipicon">
                                                <span class="tooltipcontent">
                                                    <b>Zusätzliche Tags</b> = Übergib diese Tags, zusätzlich zu der gobalen Einstellung<br>
                                                    <b>Nur diese Tags</b> = Übergib nur diese Tags, statt der globalen Einstellung<br>
                                                    <b>Mit Kategorie Tags</b> = Übergib diese Tags, zusätzlich nur mit den Kategorie Tags<br>
                                                    <b>Mit Produkt Namen Tag</b> = Übergib diese Tags, zusätzlich nur mit dem Produkt Namen Tag<br>
                                                    <b>Mit globalen Tags</b> = Übergib diese Tags, zusätzlich nur mit den globalen Tags
                                                </span>
                                            </span>
                                    <?php
                                    if($product_tag) {
                                        foreach($product_tag as $key => $product_tag_id) {
                                            if($product_tag_id) {

                                            ?>
                                                <div class="category_for_posts_row">
                                                    <select class="dmwkti-product-tag" name="product[<?php echo esc_html($product_id);?>][tag][]">
                                                        <option value=""></option>
                                                        <?php 
                                                        if($all_tags) {
                                                            foreach($all_tags as $tag_id => $tag) {
                                                                $selected = '';
                                                                if($product_tag_id == $tag_id) {
                                                                    $selected = 'selected';
                                                                }
                                                                ?>
                                                                <option value="<?php echo esc_html($tag_id);?>" <?php echo esc_html($selected);?>><?php echo esc_html($tag);?></option>
                                                                <?php
                                                            }
                                                        }
                                                        ?>
                                                    </select>
                                                    <select class="status" name="product[<?php echo esc_html($product_id);?>][status][]">
                                                        <option value="">Status Alle</option>
                                                        <option value="pending" <?php if($product_status[$key] == 'pending') {echo 'selected'; } ?> >Zahlung ausstehend</option>
                                                        <option value="processing" <?php if($product_status[$key] == 'processing') {echo 'selected'; } ?> >In Bearbeitung</option>
                                                        <option value="on-hold" <?php if($product_status[$key] == 'on-hold') {echo 'selected'; } ?> >In Wartestellung</option>
                                                        <option value="completed" <?php if($product_status[$key] == 'completed') {echo 'selected'; } ?> >Abgeschlossen</option>
                                                        <option value="cancelled" <?php if($product_status[$key] == 'cancelled') {echo 'selected'; } ?> >Storniert</option>
                                                        <option value="refunded" <?php if($product_status[$key] == 'refunded') {echo 'selected'; } ?> >Rückerstattet</option>
                                                        <option value="failed" <?php if($product_status[$key] == 'failed') {echo 'selected'; } ?> >Fehlgeschlagen</option>
                                                    </select>
                                                </div>
                                        <?php }
                                        }
                                    }
                                    ?>
                                    </div>
                                </td>

                            </tr>
                            <?php }
                        }
                    }
                    else {
                        if($products) {
                            $prod_nr = 1;
                            ksort($products);
                            foreach($products as $product_id => $product_name) {
                                $product_setting = $product_free[$product_id]['setting'];
                                $product_tag = $product_free[$product_id]['tag'];
                                $product_status = $product_free[$product_id]['status'];

                                if($prod_nr > 1) {
                                    $disabled = 'disabled';
                                }
                                else {
                                    $disabled = '';
                                }

                                $prod_nr++;
                                ?>
                            <tr>
                                <th class="product-title" scope="row"><?php echo esc_html($product_name);?></th>
                                <td><div class="category_for_posts_row">
                                    <?php
                                    if($disabled == '' and $product_tag) {
                                        $selected_break = '';
                                        foreach($product_tag as $key => $product_tag_id) {
                                            if($product_tag_id) {
                                            ?>
                                                <select class="dmwkti-product-tag2" name="product[<?php echo esc_html($product_id);?>][tag][]">
                                                    <option value=""></option>
                                                    <?php 
                                                    if($all_tags) {
                                                        foreach($all_tags as $tag_id => $tag) {
                                                            $selected = '';
                                                            if($product_tag_id == $tag_id) {
                                                                $selected = 'selected';
                                                                $selected_break = '1';
                                                            }
                                                            ?>
                                                            <option value="<?php echo esc_html($tag_id);?>" <?php echo esc_html($selected);?>><?php echo esc_html($tag);?></option>
                                                            <?php
                                                        }
                                                    }
                                                    ?>
                                                </select>
                                                <select class="status" name="product[<?php echo esc_html($product_id);?>][status][]" <?php echo esc_html($disabled);?>>
                                                    <option value="">Status Alle</option>
                                                    <option value="pending" <?php if($product_status[$key] == 'pending') {echo 'selected'; } ?> >Zahlung ausstehend</option>
                                                    <option value="processing" <?php if($product_status[$key] == 'processing') {echo 'selected'; } ?> >In Bearbeitung</option>
                                                    <option value="on-hold" <?php if($product_status[$key] == 'on-hold') {echo 'selected'; } ?> >In Wartestellung</option>
                                                    <option value="completed" <?php if($product_status[$key] == 'completed') {echo 'selected'; } ?> >Abgeschlossen</option>
                                                    <option value="cancelled" <?php if($product_status[$key] == 'cancelled') {echo 'selected'; } ?> >Storniert</option>
                                                    <option value="refunded" <?php if($product_status[$key] == 'refunded') {echo 'selected'; } ?> >Rückerstattet</option>
                                                    <option value="failed" <?php if($product_status[$key] == 'failed') {echo 'selected'; } ?> >Fehlgeschlagen</option>

                                                </select>
                                        <?php
                                                if($selected_break == '1') {
                                                    break;
                                                } 
                                            }
                                        }
                                    }
                                    else {
                                    ?>
                                        <select class="dmwkti-product-tag2" name="product[<?php echo esc_html($product_id);?>][tag][]" <?php echo esc_html($disabled);?> >
                                            <option value=""></option>
                                            <?php 
                                            if($disabled and $all_tags) {
                                                foreach($all_tags as $tag_id => $tag) {
                                                    $selected = '';
                                                    if($product_tag_id == $tag_id) {
                                                        #$selected = 'selected';
                                                    }
                                                    ?>
                                                    <option value="<?php echo esc_html($tag_id);?>" <?php echo esc_html($selected);?>><?php echo esc_html($tag);?></option>
                                                    <?php
                                                }
                                            }

                                            else if($all_tags) {
                                                foreach($all_tags as $tag_id => $tag) {
                                                    $selected = '';
                                                    if($product_tag_id == $tag_id) {
                                                        $selected = 'selected';
                                                    }
                                                    ?>
                                                    <option value="<?php echo esc_html($tag_id);?>" <?php echo esc_html($selected);?>><?php echo esc_html($tag);?></option>
                                                    <?php
                                                }
                                            }
                                            ?>
                                        </select>
                                        <select class="status" name="product[<?php echo esc_html($product_id);?>][status][]">
                                            <option value="">Status Alle</option>
                                            <option value="pending">Zahlung ausstehend</option>
                                            <option value="processing">In Bearbeitung</option>
                                            <option value="on-hold">In Wartestellung</option>
                                            <option value="completed">Abgeschlossen</option>
                                            <option value="cancelled">Storniert</option>
                                            <option value="refunded">Rückerstattet</option>
                                            <option value="failed">Fehlgeschlagen</option>
                                        </select>
                                    <?php } ?>
                                        <select name="product[<?php echo esc_html($product_id);?>][setting]" disabled>
                                                <option value="add" <?php echo ($product_setting == 'add' ? 'selected' : ''); ?> >Zusätzliche Tags</option>
                                                <option value="only" <?php echo ($product_setting == 'only' ? 'selected' : ''); ?> >Nur diese Tags</option>
                                                <option value="category" <?php echo ($product_setting == 'category' ? 'selected' : ''); ?> >Mit Kategorie Tag</option>
                                                <option value="prod_name" <?php echo ($product_setting == 'prod_name' ? 'selected' : ''); ?> >Mit Produkt Namen Tag</option>
                                                <option value="glob_tag" <?php echo ($product_setting == 'glob_tag' ? 'selected' : ''); ?> >Mit globalen Tags</option>
                                        </select>
                                        <span class="tooltipicon">?
                                            <span class="tooltipcontent">
                                                <b>Zusätzliche Tags</b> = Übergib diese Tags, zusätzlich zu der gobalen Einstellung<br>
                                                <b>Nur diese Tags</b> = Übergib nur diese Tags, statt der globalen Einstellung<br>
                                                <b>Mit Kategorie Tags</b> = Übergib diese Tags, zusätzlich nur mit den Kategorie Tags<br>
                                                <b>Mit Produkt Namen Tag</b> = Übergib diese Tags, zusätzlich nur mit dem Produkt Namen Tag<br>
                                                <b>Mit globalen Tags</b> = Übergib diese Tags, zusätzlich nur mit den globalen Tags
                                            </span>
                                        </span>
                                    </div>
                                </td>
                            </tr>
                            <?php }
                        }
                    }
                    ?>
                </tbody>
            </table>

            <div id="pagination-box"><div id="pagination">
            <?php
            if($products and $product_total_products > 20) {
                $current_page = intval($p);
                for($i = 1; $i <= $product_total_pages; $i++) {
                    $first_dots = '';
                    $active = '';
                    if($i == $current_page) {
                        $active = 'active';
                    }
                    if($product_total_pages > 20) {
                        if($i == 1 and $current_page > 5 ) {
                            $first_dots = '...';
                        }
                        else if($i == $product_total_pages and $current_page < ($product_total_pages - 5) ) {
                            echo '...';
                        }
                        else if($i < ($current_page - 4 ) ) {
                            continue;
                        }
                        else if($i > ($current_page + 4 ) ) {
                            continue;
                        }
                    }
                    echo '<a class="'.esc_html($active).'" href="?page='.esc_html($_GET['page']).'&sumit='.esc_html($submit).'&p='.esc_html($i).'#product-settings">'.esc_html($i).'</a>'.esc_html($first_dots);
                }
            }
            ?>
            </div></div>

            <br>

                <hr>

                <h3>Checkbox beim Checkout (Kasse)</h3>

                <p>Setzte eine Checkbox beim Checkout und verbinde die Checkbox mit einem Tag. Zum Beispiel für "Newsletter Eintragen"</p>

                <table class="form-table">
                    <tbody>
                    <tr>
                        <th style="padding: 0px 10px 5px 0;" scope="row">Aktiv</th>
                        <td style="padding: 0px 10px 5px 10px;">
                            <div class="category_for_posts_row">
                                <input type="checkbox" <?php if(get_option('dmwkti_checkbox_checkout') == '1') {echo 'checked';}?> name="dmwkti_checkbox_checkout" value="1">
                            </div>
                        </td>
                    </tr>
                    <tr>
                        <th style="padding: 0px 10px 5px 0;" scope="row">Checkbox Text</th>
                        <td style="padding: 0px 10px 5px 10px;">
                            <div class="category_for_posts_row">
                                <input style="width: 400px;" type="text" name="dmwkti_checkbox_checkout_title" value="<?php echo esc_html(get_option('dmwkti_checkbox_checkout_title'));?>">
                            </div>
                        </td>
                    </tr>
                    <tr>
                        <th style="padding: 0px 10px 5px 0;" scope="row">Klick Tipp Tag</th>
                        <td style="padding: 0px 10px 5px 10px;">
                            <div class="category_for_posts_row">
                                <div class="category_for_posts_row">
                                    <div class="category_for_posts_row">
                                        <select class="" name="dmwkti_checkbox_checkout_tag">
                                            <option value=""></option>
                                            <?php
                                            if($all_tags) {
                                                foreach($all_tags as $tag_id => $tag) {
                                                    $selected = '';
                                                    if(get_option('dmwkti_checkbox_checkout_tag') == $tag_id) {
                                                        $selected = 'selected';
                                                    }
                                                    ?>
                                                    <option value="<?php echo esc_html($tag_id);?>" <?php echo esc_html($selected);?>><?php echo esc_html($tag);?></option>
                                                    <?php
                                                }
                                            }
                                            ?>
                                        </select>
                                    </div>
                                </div>
                            </div>
                        </td>
                    </tr>
                    <tr>
                        <th style="padding: 0px 10px 5px 0;" scope="row">Position der Checkbox</th>
                        <td style="padding: 0px 10px 5px 10px;">
                            <div class="category_for_posts_row">
                                <select class="" name="dmwkti_checkbox_checkout_position">
                                    <option value="woocommerce_checkout_order_review" <?php if(get_option('dmwkti_checkbox_checkout_position') == 'woocommerce_checkout_order_review') {echo 'selected';} ?> >Position - Über Bestellübersicht</option>
                                    <option value="woocommerce_checkout_before_order_review_heading" <?php if(get_option('dmwkti_checkbox_checkout_position') == 'woocommerce_checkout_before_order_review_heading') {echo 'selected';} ?> >Position - Vor Bestellung bei Überschrift</option>
                                    <option value="woocommerce_review_order_before_submit" <?php if(get_option('dmwkti_checkbox_checkout_position') == 'woocommerce_review_order_before_submit') { echo 'selected';} ?> >Position - Über dem Kauf-Button</option>
                                </select>
                            </div>
                        </td>
                    </tr>

                    </tbody>
                </table>

                <hr>

            <?php } 

            submit_button();
          ?>       
      </form>

        <hr>

        <br>


        <?php if($license == 'OK') { ?>
            <h3>Bestellungen nach nach Klick Tipp importieren</h3>

            <div>
                <p>Beim Importieren werden alle bisherigen Bestellungen mit den gespeicherten Einstellungen (Tags, Opt-In Prozess) nach Klick Tipp importiert. Zuerst Änderungen speichern, danach importieren.</p>
                <a href="?page=<?php echo esc_html($_GET['page']);?>&import_all_orders=1">Alle Bestellungen nach Klick Tipp Importieren</a> (Kann mehrere Minuten dauern)
            </div>
        <?php } else { ?>
            <h3>Import nach Klick Tipp (Nur in der Vollversion)</h3>
            <div>
                <p>Beim Importieren werden alle bisherigen Bestellungen mit den gespeicherten Einstellungen (Tags, Opt-In Prozess) nach Klick Tipp importiert. Zuerst Änderungen speichern, danach importieren.</p>

                <a style="background-color:#FE004E;border-color:#FE004E;" class="button button-primary" target="_blank" href="https://digimastertools.com/">Auf Vollversion upgraden</a>
            </div>
        <?php } ?>

    </div>
    <script type="text/javascript">
    window.onload = function () {
        jQuery(function ($) {

            $(document).on('change','.dmwkti-product-tag', function(){
                // copy product-tag select
                if($(this).val() == "") {
                    $(this).parent().remove();
                }
                if( $(this).find(":selected").text() != "") {

                    var create_select = '1';
                    var container = $(this).parent().parent();

                    // check if exists empty select
                    $(container).find(".dmwkti-product-tag").each(function() {
                        //console.log( $(this).val() )
                        if($(this).val() == '') {
                            create_select = 0;
                        }
                    });
                    // create only is no empty select available
                    if(create_select) {
                        var row = $(this).parent().clone(); // div row
                        var select = $(this).clone(); // selected select

                        // status select
                        var select_status = $(this).next(".status").clone();

                        console.log(select_status)

                        // insert both select
                        var clone_row = row.html(select.prop("selectedIndex", 0) .add(select_status) );  // select set to default

                        //var clone_row = row.html(select.prop("selectedIndex", 0));  // select set to default
                        clone_row.insertAfter( $(this).parent() ); // create new element

                    }
                }
            });


        });
    }
    </script>
<?php 
}

// add Checkout Checkbox
if(get_option('dmwkti_checkbox_checkout') == 1) {

    $checkbox_position = get_option('dmwkti_checkbox_checkout_position');
    if(empty($checkbox_position)) {
        $checkbox_position = 'woocommerce_review_order_before_submit';
    }

    // Checkbox bei Checkout / Kasse ausgeben
    # https://www.tychesoftwares.com/woocommerce-checkout-page-hooks-visual-guide-with-code-snippets/
    add_action( $checkbox_position, 'dm_email_sync_add_checkout_checkbox', 10 );
    #add_action( 'woocommerce_review_order_before_submit', 'dm_email_sync_add_checkout_checkbox', 10 );

    #Add WooCommerce additional Checkbox checkout field
    function dm_email_sync_add_checkout_checkbox() {
        woocommerce_form_field( 'dmwkti_checkout_checkbox', array( // CSS ID
            'type'          => 'checkbox',
            'class'         => array('form-row mycheckbox'), // CSS Class
            'label_class'   => array('woocommerce-form__label woocommerce-form__label-for-checkbox checkbox'),
            'input_class'   => array('woocommerce-form__input woocommerce-form__input-checkbox input-checkbox'),
            'required'      => false, // Mandatory or Optional
            'label'         => get_option('dmwkti_checkbox_checkout_title'), // Label and Link
        ));
    }
}


// Einstellungen speichern
if($_POST and isset($_GET['page']) and $_GET['page'] == 'digimastertools-email-sync-setting') {

    #echo '<pre>';print_r($_POST); echo '</pre>';exit;

    // release license
    if($_GET['license'] == 'release') {
        
        // lizenz leeren
        $KlickTipp = new EmailSyncDigiMasterTools_Connect();
        $license_domain = $KlickTipp->license_domain;

        $domain = sanitize_url($_SERVER['SERVER_NAME']);
        $licensekey = get_option('dmwkti_license');
        $url = $license_domain.'/license_assistent/release-license?domain='.$domain.'&licensekey='.$licensekey;
        $result = '';
        $response = wp_remote_get( $url );
        $result = wp_remote_retrieve_body( $response );

        $_SESSION['DMWKTI_license_error'] = $result;

        // delete license
        update_option( 'dmwkti_license', '');

        header('Location: /wp-admin/admin.php?page=digimastertools-email-sync-setting');
        exit;
    }

    // update global settings
    if (isset($_POST['dmwkti_username']) or isset($_POST['dmwkti_password'])) {

        $dmwkti_username = sanitize_text_field( $_POST['dmwkti_username'] );
        $dmwkti_password = sanitize_text_field( $_POST['dmwkti_password'] );
        $dmwkti_license = sanitize_text_field( $_POST['dmwkti_license'] );
        $dmwkti_optin = sanitize_text_field( $_POST['dmwkti_optin'] );

        $_SESSION['DMWKTI_save_settings'] = 'Gespeichert';

        update_option( 'dmwkti_username', $dmwkti_username );
        update_option( 'dmwkti_password', $dmwkti_password );
        update_option( 'dmwkti_license', $dmwkti_license );
        update_option( 'dmwkti_optin',  $dmwkti_optin);

                #update_option( 'dmwkti_product_image_url', sanitize_text_field( $_POST['dmwkti_product_image_url'] ) );
                #update_option( 'dmwkti_product_name', sanitize_text_field( $_POST['dmwkti_product_name'] ) );
                #update_option( 'dmwkti_product_id', sanitize_text_field( $_POST['dmwkti_product_id'] ) );

        if($_POST['dmwkti_plugin_license'] == 'paid') {

            $dmwkti_tag_category = sanitize_text_field( $_POST['dmwkti_tag_category'] );
            $dmwkti_tag_product_name = sanitize_text_field( $_POST['dmwkti_tag_product_name'] );

            update_option( 'dmwkti_tag_category', $dmwkti_tag_category );
            update_option( 'dmwkti_tag_product_name', $dmwkti_tag_product_name );

            $dmwkti_global_tag = sanitize_post($_POST['dmwkti_global_tag']);
            unset($dmwkti_global_tag['ID']);
            unset($dmwkti_global_tag['filter']);

            $dmwkti_global_tag_status = sanitize_post($_POST['dmwkti_global_tag_status']);
            unset($dmwkti_global_tag_status['ID']);
            unset($dmwkti_global_tag_status['filter']);

            #echo '<pre>';print_r($_POST); echo '</pre>';exit;

            // update global tags
            if($dmwkti_global_tag) {
                $tmp_array = array();
                foreach($dmwkti_global_tag as $key => $val) {
                    if($val) {
                        #$tmp_array[] = $val;
                        $tmp_array[] = array(
                            'tag' => sanitize_text_field( $val ),
                            'status' => sanitize_text_field( $dmwkti_global_tag_status[$key] )
                        );
                    }
                }
                $jason_global_tag = json_encode($tmp_array);
                update_option( 'dmwkti_global_tag', $jason_global_tag );
            }
        }

        // lizenz speichern und übertragen

        // if domain is not set or new name
        // ....

        $KlickTipp = new EmailSyncDigiMasterTools_Connect();
        $license_domain = $KlickTipp->license_domain;

        $domain = sanitize_url($_SERVER['SERVER_NAME']);

        $licensekey = sanitize_text_field( $_POST['dmwkti_license'] );
                #$url = $license_domain.'/license_assistent/import-register-license?domain='.$domain.'&email='.$email.'&licensekey='.$licensekey;
        $url = $license_domain.'/license_assistent/import-register-license?domain='.$domain.'&licensekey='.$licensekey;
        $result = '';
        $response = wp_remote_get( $url );
        $result = wp_remote_retrieve_body( $response );

        $_SESSION['DMWKTI_license_error'] = $result;
        #echo '<pre>';print_r($result); echo '</pre>';exit;
    }

    // update products
    if ($_POST['wktiform-product-settings']) {

        $_SESSION['DMWKTI_save_settings'] = 'Gespeichert';

        $dmwkti_checkbox_checkout = sanitize_text_field( $_POST['dmwkti_checkbox_checkout'] );
        $dmwkti_checkbox_checkout_title = sanitize_text_field( $_POST['dmwkti_checkbox_checkout_title'] );
        $dmwkti_checkbox_checkout_tag = sanitize_text_field( $_POST['dmwkti_checkbox_checkout_tag'] );
        $dmwkti_checkbox_checkout_position = sanitize_text_field( $_POST['dmwkti_checkbox_checkout_position'] );

        // checkbox for Checkout
        update_option( 'dmwkti_checkbox_checkout', $dmwkti_checkbox_checkout );
        update_option( 'dmwkti_checkbox_checkout_title', $dmwkti_checkbox_checkout_title );
        update_option( 'dmwkti_checkbox_checkout_tag', $dmwkti_checkbox_checkout_tag );
        update_option( 'dmwkti_checkbox_checkout_position', $dmwkti_checkbox_checkout_position );

        $product_array = sanitize_post($_POST['product']);
        unset($product_array['ID']);
        unset($product_array['filter']);

        if($_POST['dmwkti_plugin_license'] == 'paid') {

            // update product tags
            if($product_array) {
                $tmp_array = array();

                        /*
                        // old save via option settings
                        #$tmp_array = get_option('dmwkti_product');
                        #$jason_load_product = json_decode($tmp_array);
                        foreach($product_array as $prod_id => $product) {
                            $tmp_array[$prod_id]['setting'] = $product['setting'];
                            if($product['tag']) {
                                foreach($product['tag'] as $key => $tag) {
                                    if($tag) {
                                        $tmp_array[$prod_id]['tag'][] = sanitize_text_field( $tag );
                                        // status
                                        $tmp_array[$prod_id]['status'][] = sanitize_text_field( $product['status'][$key] );
                                    }
                                }
                            }
                        }
                        #echo '<pre>';print_r($_POST); echo '</pre>';
                        $jason_product_data = json_encode($tmp_array);
                        update_option( 'dmwkti_product', $jason_product_data );
                        */


                // for each product, save in product post_meta
                foreach($product_array as $id => $settings) {

                    $tag_array = array();
                    $status_array = array();

                    $tmp_array['setting'] = $settings['setting'];
                    if($settings['tag']) {
                        foreach($settings['tag'] as $key => $tag) {
                            if($tag) {
                                $tag_array[] = sanitize_text_field( $tag );
                                $status_array[] = sanitize_text_field( $settings['status'][$key] );
                            }
                        }
                    }

                    $settings_array = array(
                        'setting' => sanitize_text_field( $settings['setting'] ),
                        'tag' => $tag_array,
                        'status' => $status_array,
                    );
                    update_post_meta($id, 'dmwkti_product_settings', json_encode($settings_array));

                }
            }
        }
        else if($_POST['dmwkti_plugin_license'] == 'free') {
            // update product tags
            if($product_array) {
                $tmp_array = array();
                #$tmp_array = get_option('dmwkti_product');
                #$jason_load_product = json_decode($tmp_array);
                $tmp_array = array();
                foreach($product_array as $prod_id => $product) {
                    $tmp_array[$prod_id]['setting'] = $product['setting'];
                    if($product['tag']) {
                        foreach($product['tag'] as $key => $tag) {
                            if($tag) {
                                $tmp_array[$prod_id]['tag'][] = sanitize_text_field( $tag );

                                // status
                                $tmp_array[$prod_id]['status'][] = sanitize_text_field( $product['status'][$key] );
                            }
                        }
                    }
                }

                $jason_product_data = json_encode($tmp_array);
                update_option( 'dmwkti_product_free', $jason_product_data );
            }
        }

    }
}

//hook thank you page
// aufruf egal welcher status
add_action( 'woocommerce_thankyou', 'dm_email_sync_thank_you_page', 10, 1);
function dm_email_sync_thank_you_page($order_id) {
    $KlickTipp = new EmailSyncDigiMasterTools_Connect();
    $KlickTipp->checkout_process_to_klicktipp($order_id);
}

// checkout create order
# https://woocommerce.github.io/code-reference/hooks/hooks.html

//bei Bestellung des Produkts und Status Zahlung ausstehend
add_action( 'woocommerce_checkout_order_created', 'dm_email_sync_woocommerce_order_status_changed');

// hook order status changed
add_action( 'woocommerce_order_status_pending', 'dm_email_sync_woocommerce_order_status_changed');
add_action( 'woocommerce_order_status_failed', 'dm_email_sync_woocommerce_order_status_changed');
add_action( 'woocommerce_order_status_on-hold', 'dm_email_sync_woocommerce_order_status_changed');
add_action( 'woocommerce_order_status_processing', 'dm_email_sync_woocommerce_order_status_changed');
add_action( 'woocommerce_order_status_completed', 'dm_email_sync_woocommerce_order_status_changed');
add_action( 'woocommerce_order_status_refunded', 'dm_email_sync_woocommerce_order_status_changed');
add_action( 'woocommerce_order_status_cancelled', 'dm_email_sync_woocommerce_order_status_changed');
function dm_email_sync_woocommerce_order_status_changed($order_id) {
    $KlickTipp = new EmailSyncDigiMasterTools_Connect();
    $KlickTipp->checkout_process_to_klicktipp($order_id);
}

/*
<option value="">Status Alle</option>
<option value="pending">Zahlung ausstehend</option>
<option value="processing">In Bearbeitung</option>
<option value="on-hold">In Wartestellung</option>
<option value="completed">Abgeschlossen</option>
<option value="cancelled">Storniert</option>
<option value="refunded">Rückerstattet</option>
<option value="failed">Fehlgeschlagen</option>
*/

add_action('woocommerce_add_to_cart', 'dm_email_sync_add_to_cart', 10, 3 );
#add_filter( 'woocommerce_add_cart_item_data', 'dm_email_sync_add_to_cart',1,1 );
#function woo_custom_add_to_cart( $cart_item_data,$productId ) {
 #   var_dump($productId);
#}

function dm_email_sync_add_to_cart($cart_item_data, $product_id) {

    #global $woocommerce;

    // if user is login
    $user_id = get_current_user_id();
    if($user_id) {
        $user_info = get_userdata($user_id);
        $user_email = $user_info->user_email;

        $product_id = $product_id;

        // send product data zu klick tipp
        if($user_email) {
            #$field_product_image_url = get_option('dmwkti_product_image_url');
            #$field_product_name = get_option('dmwkti_product_name');
            #$field_produt_id = get_option('dmwkti_product_id');

            $product   = wc_get_product( $product_id );
            $product_title = $product->get_title();
            $image_id  = $product->get_image_id();
            $image_url = '';
            if($image_id) {
                $image_url = wp_get_attachment_image_url( $image_id, 'full' );
            }

            // custom fields
            $fields = array(
                #$field_produt_id => $product_id,
                #$field_product_name => $product_title,
                #$field_product_image_url => $image_url,
            );

            $listid = '';
            // set double opt in
            if(get_option('dmwkti_optin')) {
                $listid = get_option('dmwkti_optin');
            }
            else {
               $listid = 0;
            }

            $KlickTipp = new EmailSyncDigiMasterTools_Connect();
            $KlickTipp->api->subscribe($user_email, $listid, $tagid = 0, $fields, $smsnumber = '');

        }
    }
}